pub struct ZwpConfinedPointerV1 { /* private fields */ }Expand description
confined pointer object
The wp_confined_pointer interface represents a confined pointer state.
This object will send the event ‘confined’ when the confinement is activated. Whenever the confinement is activated, it is guaranteed that the surface the pointer is confined to will already have received pointer focus and that the pointer will be within the region passed to the request creating this object. It is up to the compositor to decide whether this requires some user interaction and if the pointer will warp to within the passed region if outside.
To unconfine the pointer, send the destroy request. This will also destroy the wp_confined_pointer object.
If the compositor decides to unconfine the pointer the unconfined event is sent. The wp_confined_pointer object is at this point defunct and should be destroyed.
See also the Request enum for this interface.
Implementations
Sourceimpl ZwpConfinedPointerV1
impl ZwpConfinedPointerV1
Sourcepub fn confined(&self)
pub fn confined(&self)
pointer confined
Notification that the pointer confinement of the seat’s pointer is activated.
Sourcepub fn unconfined(&self)
pub fn unconfined(&self)
pointer unconfined
Notification that the pointer confinement of the seat’s pointer is no longer active. If this is a oneshot pointer confinement (see wp_pointer_constraints.lifetime) this object is now defunct and should be destroyed. If this is a persistent pointer confinement (see wp_pointer_constraints.lifetime) this pointer confinement may again reactivate in the future.